@@ -160,18 +160,19 @@ test_that("pk.calc.kel", {
 
 test_that("pk.calc.cl", {
   ## Ensure that dose and auc are required
-  expect_error(pk.calc.cl(auc=NA))
-  expect_error(pk.calc.cl(dose=NA))
+  expect_error(pk.calc.cl(aucinf=NA),
+               info="dose is required for clearance calculation")
+  expect_error(pk.calc.cl(dose=NA),
+               info="aucinf is required for clearance calculation")
 
-  ## Estimate a single CL
-  expect_equal(pk.calc.cl(10, 100), 0.1)
-  ## Estimate multiple CLs from a single dose level (including some
-  ## NA)
-  expect_equal(pk.calc.cl(10, c(10, NA, 100)),
-               c(1, NA, 0.1))
-  ## Do unit conversion
-  expect_equal(pk.calc.cl(10, c(10, NA, 100), 1000),
-               c(1, NA, 0.1)*1000)
+  expect_equal(pk.calc.cl(dose=10, aucinf=100), 0.1,
+               info="Normal clearance calcualtion works")
+  expect_equal(pk.calc.cl(dose=c(10, 10, 10), aucinf=c(10, NA, 100)),
+               c(1, NA, 0.1),
+               info="Vectors for both dose and aucinf give vectors for clearance (with NAs)")
+  expect_equal(pk.calc.cl(dose=c(50, 50), aucinf=100),
+               1,
+               info="Vector for dose and scalar for aucinf scalar output with the sum of doses")
 })
 
 test_that("pk.calc.f", {
@@ -192,49 +193,47 @@ test_that("pk.calc.mrt", {
 })
 
 test_that("pk.calc.vz", {
-  ## Ensure that dose, auc, and kel are required
-  expect_error(pk.calc.vz(auc=NA, kel=NA))
-  expect_error(pk.calc.vz(dose=NA, kel=NA))
-  expect_error(pk.calc.vz(auc=NA, dose=NA))
+  ## Ensure that cl and lambda.z are required
+  expect_equal(pk.calc.vz(cl=NA, lambda.z=NA), NA_integer_)
+  expect_error(pk.calc.vz(cl=NA),
+               info="lambda.z required for Vz calculation")
+  expect_error(pk.calc.vz(lambda.z=NA),
+               info="CL required for Vz calculation")
 
-  ## Ensure that dose is either 1 or the same length as AUC
-  expect_error(pk.calc.vz(dose=c(1, 2), auc=1:4, kel=1:4),
-               regexp="'dose' and 'auc' must be the same length")
-  ## Ensure that auc and kel are the same length
-  expect_error(pk.calc.vz(dose=1, auc=1:4, kel=1:3),
-               regexp="'auc' and 'kel' must be the same length")
+  ## Ensure that length of cl and lambda.z are either 1 or the same length
+  expect_error(pk.calc.vz(cl=1:2, lambda.z=1:3),
+               regexp="'cl' and 'lambda.z' must be the same length",
+               info="CL and lambda.z must be the same length (CL shorter)")
+  expect_error(pk.calc.vz(cl=1:3, lambda.z=1:2),
+               regexp="'cl' and 'lambda.z' must be the same length",
+               info="CL and lambda.z must be the same length (lambda.z shorter)")
   
   ## Estimate a single Vz (with permutations to ensure the right math
   ## is happening)
-  expect_equal(pk.calc.vz(dose=1, auc=1, kel=1), 1)
-  expect_equal(pk.calc.vz(dose=1, auc=1, kel=2), 0.5)
-  expect_equal(pk.calc.vz(dose=1, auc=2, kel=1), 0.5)
-  expect_equal(pk.calc.vz(dose=1, auc=2, kel=2), 0.25)
-  expect_equal(pk.calc.vz(dose=2, auc=1, kel=1), 2)
-  expect_equal(pk.calc.vz(dose=2, auc=1, kel=2), 1)
-  expect_equal(pk.calc.vz(dose=2, auc=2, kel=1), 1)
-  expect_equal(pk.calc.vz(dose=2, auc=2, kel=2), 0.5)
+  expect_equal(pk.calc.vz(cl=1, lambda.z=1), 1,
+               info="vz math test 1")
+  expect_equal(pk.calc.vz(cl=1, lambda.z=2), 0.5,
+               info="vz math test 2")
+  expect_equal(pk.calc.vz(cl=2, lambda.z=1), 2,
+               info="vz math test 3")
+  expect_equal(pk.calc.vz(cl=2, lambda.z=2), 1,
+               info="vz math test 4")
 
-  ## Ensure that NA can go into any position
-  expect_equal(pk.calc.vz(dose=NA, auc=1, kel=1),
-               as.numeric(NA))
-  expect_equal(pk.calc.vz(dose=1, auc=NA, kel=1),
-               as.numeric(NA))
-  expect_equal(pk.calc.vz(dose=1, auc=1, kel=NA),
-               as.numeric(NA))
+  ## Ensure that NA can go into either position or both
+  expect_equal(pk.calc.vz(cl=NA, lambda.z=1), NA_integer_,
+               info="Vz with missing (NA) cl")
+  expect_equal(pk.calc.vz(cl=1, lambda.z=NA), NA_integer_,
+               info="Vz with missing (NA) lambda.z")
+  expect_equal(pk.calc.vz(cl=NA, lambda.z=NA), NA_integer_,
+               info="Vz with missing (NA) lambda.z and cl")
 
-  ## Estimate multiple Vzs from a single dose level (including some
-  ## NA)
-  expect_equal(pk.calc.vz(dose=10,
-                          auc=c(10, NA, 100),
-                          kel=c(2, 2, 2)),
-               c(0.5, NA, 0.05))
-  ## Do unit conversion
-  expect_equal(pk.calc.vz(dose=10,
-                          auc=c(10, NA, 100),
-                          kel=c(2, 2, 2),
-                          unitconv=1000),
-               c(0.5, NA, 0.05)*1000)
+  ## vectorized vz calculation works
+  expect_equal(pk.calc.vz(cl=
+                            c(1, 1, 1, 2, 2, 2, NA, NA, NA),
+                          lambda.z=
+                            c(1, 2, NA, 1, 2, NA, 1, 2, NA)),
+               c(1, 0.5, NA, 2, 1, NA, NA, NA, NA),
+               info="Vz with vector inputs including missing values for both parameters (cl and lambda.z)")
 })
 
 test_that("pk.calc.vss", {
@@ -244,10 +243,19 @@ test_that("pk.calc.vss", {
 })
 
 test_that("pk.calc.vd", {
-  expect_equal(pk.calc.vd(1, 2, 3), 1/6)
-  expect_equal(pk.calc.vd(NA, 2, 3), as.numeric(NA))
-  expect_equal(pk.calc.vd(1, NA, 3), as.numeric(NA))
-  expect_equal(pk.calc.vd(1, 2, NA), as.numeric(NA))
+  expect_equal(pk.calc.vd(1, 2, 3), 1/6,
+               info="Normal Vd calculation works")
+  expect_equal(pk.calc.vd(NA, 2, 3), NA_integer_,
+               info="Vd calculation returns NA when dose is NA")
+  expect_equal(pk.calc.vd(1, NA, 3), NA_integer_,
+               info="Vd calculation returns NA when aucinf is NA")
+  expect_equal(pk.calc.vd(1, 2, NA), NA_integer_,
+               info="Vd calculation returns NA when lambda.z is NA")
+  
+  expect_equal(pk.calc.vd(c(1, 2), c(2, 4), c(3, 6)), c(1/6, 1/12),
+               info="Vd calculation works with three vector inputs returning a vector")
+  expect_equal(pk.calc.vd(c(1, 2), 2, 3), 0.5,
+               info="Vd calculation works with vector dose and scalar aucinf and lambda.z inputs returning a scalar with the sum of doses used.")
 })
 
 test_that("pk.calc.cav", {
